ParserBuilder

Struct ParserBuilder 

pub struct ParserBuilder<R: BufRead, S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<R: BufRead, S: State> ParserBuilder<R, S>

pub fn build(self, reader: R) -> Parser<R>
where S: IsComplete,

Instantiate a parser with the provided reader as input

pub fn enable_extended_globbing( self, value: bool, ) -> ParserBuilder<R, SetEnableExtendedGlobbing<S>>
where S::EnableExtendedGlobbing: IsUnset,

Optional (Some / Option setters). Default: true.

Whether or not to enable extended globbing (a.k.a. extglob).

pub fn maybe_enable_extended_globbing( self, value: Option<bool>, ) -> ParserBuilder<R, SetEnableExtendedGlobbing<S>>
where S::EnableExtendedGlobbing: IsUnset,

Optional (Some / Option setters). Default: true.

Whether or not to enable extended globbing (a.k.a. extglob).

pub fn posix_mode(self, value: bool) -> ParserBuilder<R, SetPosixMode<S>>
where S::PosixMode: IsUnset,

Optional (Some / Option setters). Default: false.

Whether or not to enable POSIX compliance mode.

pub fn maybe_posix_mode( self, value: Option<bool>, ) -> ParserBuilder<R, SetPosixMode<S>>
where S::PosixMode: IsUnset,

Optional (Some / Option setters). Default: false.

Whether or not to enable POSIX compliance mode.

pub fn sh_mode(self, value: bool) -> ParserBuilder<R, SetShMode<S>>
where S::ShMode: IsUnset,

Optional (Some / Option setters). Default: false.

Whether or not to enable maximal compatibility with the sh shell.

pub fn maybe_sh_mode( self, value: Option<bool>, ) -> ParserBuilder<R, SetShMode<S>>
where S::ShMode: IsUnset,

Optional (Some / Option setters). Default: false.

Whether or not to enable maximal compatibility with the sh shell.

pub fn tilde_expansion_at_word_start( self, value: bool, ) -> ParserBuilder<R, SetTildeExpansionAtWordStart<S>>
where S::TildeExpansionAtWordStart: IsUnset,

Optional (Some / Option setters). Default: true.

Whether or not to perform tilde expansion for tildes at the start of words.

pub fn maybe_tilde_expansion_at_word_start( self, value: Option<bool>, ) -> ParserBuilder<R, SetTildeExpansionAtWordStart<S>>
where S::TildeExpansionAtWordStart: IsUnset,

Optional (Some / Option setters). Default: true.

Whether or not to perform tilde expansion for tildes at the start of words.

pub fn tilde_expansion_after_colon( self, value: bool, ) -> ParserBuilder<R, SetTildeExpansionAfterColon<S>>
where S::TildeExpansionAfterColon: IsUnset,

Optional (Some / Option setters). Default: false.

Whether or not to perform tilde expansion for tildes after colons.

pub fn maybe_tilde_expansion_after_colon( self, value: Option<bool>, ) -> ParserBuilder<R, SetTildeExpansionAfterColon<S>>
where S::TildeExpansionAfterColon: IsUnset,

Optional (Some / Option setters). Default: false.

Whether or not to perform tilde expansion for tildes after colons.

pub fn parser_impl( self, value: ParserImpl, ) -> ParserBuilder<R, SetParserImpl<S>>
where S::ParserImpl: IsUnset,

Optional (Some / Option setters). Default: <ParserImpl as Default>::default().

Select the parser internal implementation

pub fn maybe_parser_impl( self, value: Option<ParserImpl>, ) -> ParserBuilder<R, SetParserImpl<S>>
where S::ParserImpl: IsUnset,

Optional (Some / Option setters). Default: <ParserImpl as Default>::default().

Select the parser internal implementation